==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/libs/utils/updatechecker_p.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main developers : Eric MAEKER, <eric.maeker@gmail.com>                *
 *   Contributors :                                                        *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef UPDATECHECKERPRIVATE_H
#define UPDATECHECKERPRIVATE_H

#include <QObject>
#include <QtNetwork>
#include <QBuffer>
#include <QProgressBar>
#include <QPointer>

namespace Utils {
namespace Internal {

class UpdateCheckerPrivate : public QObject
{
     Q_OBJECT
public:
    UpdateCheckerPrivate(QObject *parent = 0);
    ~UpdateCheckerPrivate();

    void cancelDownload();
    bool getFile(const QUrl &url);
    void updateFound( const QString & );

private Q_SLOTS:
    void httpDone(bool error);
    void updateDataReadProgress(int bytesRead, int totalBytes);

public:
    QHttp *m_Http;
    QBuffer m_Buffer;
    QUrl m_Url;
    QString m_UpdateText;
    QString m_LastVersion;
    bool m_FileRetreived;
    QPointer<QProgressBar> m_ProgressBar;
};

}  // End Internal
}  // End Utils

#endif  // UPDATECHECKERPRIVATE_H

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/libs/utils/updatechecker_p.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main developer: Eric MAEKER, <eric.maeker@gmail.com>                   *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef UPDATECHECKERPRIVATE_H
#define UPDATECHECKERPRIVATE_H

#include <QObject>
#include <QProgressBar>
#include <QPointer>
#include <QUrl>

namespace Utils {
class HttpDownloader;
namespace Internal {

class UpdateCheckerPrivate : public QObject
{
     Q_OBJECT
public:
    UpdateCheckerPrivate(QObject *parent = 0);
    ~UpdateCheckerPrivate();

    void cancelDownload();
    bool getFile(const QUrl &url);
    void updateFound(const QString &);

private Q_SLOTS:
    void onDownloadFinished();

public:
    HttpDownloader *_downloader;
    QUrl m_Url;
    QString m_UpdateText;
    QString m_LastVersion;
    bool m_FileRetreived;
    QPointer<QProgressBar> m_ProgressBar;
};

}  // End Internal
}  // End Utils

#endif  // UPDATECHECKERPRIVATE_H
